@@ -12,11 +12,11 @@
 namespace Symfony\Bundle\SecurityBundle\Tests\DependencyInjection;
 
 use PHPUnit\Framework\TestCase;
-use Symfony\Component\DependencyInjection\Argument\IteratorArgument;
-use Symfony\Component\DependencyInjection\Reference;
-use Symfony\Bundle\SecurityBundle\SecurityBundle;
 use Symfony\Bundle\SecurityBundle\DependencyInjection\SecurityExtension;
+use Symfony\Bundle\SecurityBundle\SecurityBundle;
+use Symfony\Component\DependencyInjection\Argument\IteratorArgument;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
+use Symfony\Component\DependencyInjection\Reference;
 use Symfony\Component\Security\Core\Authorization\AccessDecisionManager;
 use Symfony\Component\Security\Core\Encoder\Argon2iPasswordEncoder;
 
@@ -85,7 +85,7 @@ abstract class CompleteConfigurationTest extends TestCase
             $arguments = $contextDef->getArguments();
             $listeners[] = array_map('strval', $arguments['index_0']->getValues());
 
-            $configDef = $container->getDefinition((string) $arguments['index_2']);
+            $configDef = $container->getDefinition((string) $arguments['index_3']);
             $configs[] = array_values($configDef->getArguments());
         }
 
@@ -113,7 +113,6 @@ abstract class CompleteConfigurationTest extends TestCase
                 null,
                 null,
                 array(
-                    'logout',
                     'switch_user',
                     'x509',
                     'remote_user',
@@ -162,13 +161,29 @@ abstract class CompleteConfigurationTest extends TestCase
                 ),
                 null,
             ),
+            array(
+                'simple_auth',
+                'security.user_checker',
+                null,
+                true,
+                false,
+                'security.user.provider.concrete.default',
+                'simple_auth',
+                'security.authentication.form_entry_point.simple_auth',
+                null,
+                null,
+                array(
+                  'simple_form',
+                  'anonymous',
+                ),
+                null,
+            ),
         ), $configs);
 
         $this->assertEquals(array(
             array(),
             array(
                 'security.channel_listener',
-                'security.logout_listener.secure',
                 'security.authentication.listener.x509.secure',
                 'security.authentication.listener.remote_user.secure',
                 'security.authentication.listener.form.secure',
@@ -192,6 +207,13 @@ abstract class CompleteConfigurationTest extends TestCase
                 'security.authentication.listener.anonymous.with_user_checker',
                 'security.access_listener',
             ),
+            array(
+                'security.channel_listener',
+                'security.context_listener.2',
+                'security.authentication.listener.simple_form.simple_auth',
+                'security.authentication.listener.anonymous.simple_auth',
+                'security.access_listener',
+            ),
         ), $listeners);
 
         $this->assertFalse($container->hasAlias('Symfony\Component\Security\Core\User\UserCheckerInterface', 'No user checker alias is registered when custom user checker services are registered'));
@@ -211,7 +233,7 @@ abstract class CompleteConfigurationTest extends TestCase
             $arguments = $contextDef->getArguments();
             $listeners[] = array_map('strval', $arguments['index_0']->getValues());
 
-            $configDef = $container->getDefinition((string) $arguments['index_2']);
+            $configDef = $container->getDefinition((string) $arguments['index_3']);
             $configs[] = array_values($configDef->getArguments());
         }
 
@@ -239,7 +261,6 @@ abstract class CompleteConfigurationTest extends TestCase
                 null,
                 null,
                 array(
-                    'logout',
                     'switch_user',
                     'x509',
                     'remote_user',
@@ -295,7 +316,6 @@ abstract class CompleteConfigurationTest extends TestCase
             array(),
             array(
                 'security.channel_listener',
-                'security.logout_listener.secure',
                 'security.authentication.listener.x509.secure',
                 'security.authentication.listener.remote_user.secure',
                 'security.authentication.listener.form.secure',
@@ -377,7 +397,7 @@ abstract class CompleteConfigurationTest extends TestCase
             $this->assertArrayNotHasKey($matcherId, $matcherIds);
             $matcherIds[$matcherId] = true;
 
-            $i = count($matcherIds);
+            $i = \count($matcherIds);
             if (1 === $i) {
                 $this->assertEquals(array('ROLE_USER'), $attributes);
                 $this->assertEquals('https', $channel);
