@@ -11,15 +11,13 @@
 
 namespace Symfony\Bundle\TwigBundle\DependencyInjection;
 
-use Symfony\Bridge\Twig\Extension\WebLinkExtension;
 use Symfony\Component\Config\FileLocator;
 use Symfony\Component\Config\Resource\FileExistenceResource;
 use Symfony\Component\Console\Application;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
-use Symfony\Component\DependencyInjection\Reference;
 use Symfony\Component\DependencyInjection\Loader\XmlFileLoader;
+use Symfony\Component\DependencyInjection\Reference;
 use Symfony\Component\HttpKernel\DependencyInjection\Extension;
-use Symfony\Component\WebLink\HttpHeaderSerializer;
 use Twig\Extension\ExtensionInterface;
 use Twig\Extension\RuntimeExtensionInterface;
 use Twig\Loader\LoaderInterface;
@@ -60,17 +58,10 @@ class TwigExtension extends Extension
             $container->removeDefinition('twig.translation.extractor');
         }
 
-        if (class_exists(HttpHeaderSerializer::class)) {
-            $definition = $container->register('twig.extension.weblink', WebLinkExtension::class);
-            $definition->setPublic(false);
-            $definition->addArgument(new Reference('request_stack'));
-            $definition->addTag('twig.extension');
-        }
-
         foreach ($configs as $key => $config) {
             if (isset($config['globals'])) {
                 foreach ($config['globals'] as $name => $value) {
-                    if (is_array($value) && isset($value['key'])) {
+                    if (\is_array($value) && isset($value['key'])) {
                         $configs[$key]['globals'][$name] = array(
                             'key' => $name,
                             'value' => $value,
@@ -129,7 +120,7 @@ class TwigExtension extends Extension
 
             // add exclusive namespace for root bundles only
             // to override a bundle template that also extends itself
-            if (count($bundle['paths']) > 0 && 0 === count($bundle['parents'])) {
+            if (\count($bundle['paths']) > 0 && 0 === \count($bundle['parents'])) {
                 // the last path must be the bundle views directory
                 $twigFilesystemLoaderDefinition->addMethodCall('addPath', array(end($bundle['paths']), '!'.$namespace));
             }
