@@ -11,8 +11,8 @@
 
 namespace Symfony\Component\HttpKernel\Tests\Fixtures;
 
-use Symfony\Component\HttpKernel\Kernel;
 use Symfony\Component\Config\Loader\LoaderInterface;
+use Symfony\Component\HttpKernel\Kernel;
 
 class KernelForTest extends Kernel
 {
@@ -23,32 +23,15 @@ class KernelForTest extends Kernel
 
     public function registerBundles()
     {
-    }
-
-    public function init()
-    {
-    }
-
-    public function registerBundleDirs()
-    {
+        return array();
     }
 
     public function registerContainerConfiguration(LoaderInterface $loader)
     {
     }
 
-    public function initializeBundles()
-    {
-        parent::initializeBundles();
-    }
-
     public function isBooted()
     {
         return $this->booted;
     }
-
-    public function setIsBooted($value)
-    {
-        $this->booted = (bool) $value;
-    }
 }
